const japanese = {
    month: ['1月','2月','3月','4月','5月','6月','7月','8月','9月','10月','11月','12月'],
    week: ['日','月','火','水','木','金','土']
};
const german = {
    month: ['Januar', 'Februar', 'März', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember'],
    week: ['so', 'mo', 'di', 'mi', 'do', 'fr', 'sa']
};
const portuguese = {
    month: ['janeiro', 'fevereiro', 'março', 'abril', 'maio', 'junho', 'julho', 'agosto', 'setembro', 'outubro', 'novembro', 'dezembro'],
    week: ['dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sáb']
};

const isNull = (val) => {
    if (val === null || val === undefined || val === NaN || isNaN(val)) {
        return true;
    }

    return false;
};

document.addEventListener("DOMContentLoaded", function() {
    const launch = document.getElementById('testbtn');

    launch.addEventListener('click', e => {
        e.preventDefault();
        e.stopImmediatePropagation();

        let year = document.getElementById('year');
        let month = document.getElementById('month');
        let date = document.getElementById('date');
        let hour = document.getElementById('hour');
        let minute = document.getElementById('minute');
        let disableDate = document.getElementById('disable');
        let enableYear = document.getElementById('enableyear');
        let enableMonth = document.getElementById('enablemonth');
        let enableTime = document.getElementById('enabletime');
        let translate = document.getElementById('translate');
        let holiday = document.getElementById('holidays');
    
        const options = {};
    
        year = parseInt(year.options[year.selectedIndex].value.trim());
        month = parseInt(month.options[month.selectedIndex].value.trim());
        date = parseInt(date.options[date.selectedIndex].value.trim());
        hour = parseInt(hour.options[hour.selectedIndex].value.trim());
        minute = parseInt(minute.options[minute.selectedIndex].value.trim());
        disableDate = disableDate.checked;
        enableYear = enableYear.checked;
        enableMonth = enableMonth.checked;
        enableTime = enableTime.checked;
        translate = translate.options[translate.selectedIndex].value.trim();
        holiday = holiday.checked;
    
        if (isNull(year) || year < 1900) {
            year = null;
        }
        if (isNull(month) || month < 1 || month > 12) {
            month = null;
        }
        if (isNull(date) || date < 1 || date > 31) {
            date = null;
        }
        if (isNull(hour) || hour > 23 || hour < 0) {
            hour = null;
        }
        if (isNull(minute) || minute > 59 || minute < 0) {
            minute = null;
        }
    
        if (!isNull(year)) {
            console.log('year is not null', year);
            options.year = year;
        }
    
        if (!isNull(month)) {
            options.month = month;
        }
    
        if (!isNull(date)) {
            options.date = date;
        }

        if (!isNull(hour)) {
            options.hour = hour;
        }

        if (!isNull(minute)) {
            options.minute = minute;
        }

        if (disableDate) {
            options.disabledDates = [{
                date: 10,
                month: 1,
                year: 2022
            },
            {
                date: 11,
                month: 1,
                year: 2022
            }];
        }

        if (!enableYear) {
            options.enableYearChange = false;
        }

        if (!enableMonth) {
            options.enableMonthChange = false;
        }

        if (!enableTime) {
            options.enableTimeChange = false;
        }

        switch(translate) {
            case 'j': options.translation = japanese; break;
            case 'g': options.translation = german; break;
            case 'p': options.translation = portuguese; break; 
        }

        if (holiday) {
            options.holidays = [{
                date: 25,
                month: 12,
                name: 'Christmas'
            },
            {
                date: 1,
                month: 1,
                name: 'New Year\'s'
            }];
        }

        const res = document.getElementById('content--test-options');

        // listen for events.
        options.onDate = (d) => {
            console.log(`%cjDatePicker.js [onDate] ::: ${JSON.stringify(d, undefined, 2)}`, 'background:#1b709e;color:#fff;padding:3px 5px;');
            res.innerHTML += "\r\n-------------------------------\r\n" + `[onDate] ::: ${JSON.stringify(d, undefined, 2)}`;
        };
        options.onMonth = (m) => {
            console.log(`%cjDatePicker.js [onMonth] ::: ${JSON.stringify(m, undefined, 2)}`, 'background:#1b709e;color:#fff;padding:3px 5px;');
            res.innerHTML += "\r\n-------------------------------\r\n" + `[onMonth] ::: ${JSON.stringify(m, undefined, 2)}`;
        };
        options.onCancel = () => {
            console.log(`%cjDatePicker.js [onCancel] ::: {void}`, 'background:#1b709e;color:#fff;padding:3px 5px;');
            res.innerHTML += "\r\n-------------------------------\r\n" + `[onCancel] ::: {void}`;
        };
        options.onAccept = (a) => {
            console.log(`%cjDatePicker.js [onAccept] ::: ${JSON.stringify(a, undefined, 2)}`, 'background:#1b709e;color:#fff;padding:3px 5px;');
            res.innerHTML += "\r\n-------------------------------\r\n" + `[onAccept] ::: ${JSON.stringify(a, undefined, 2)}`;
        };
        options.onTime = (t) => {
            console.log(`%cjDatePicker.js [onTime] ::: ${JSON.stringify(t, undefined, 2)}`, 'background:#1b709e;color:#fff;padding:3px 5px;');
            res.innerHTML += "\r\n-------------------------------\r\n" + `[onTime] ::: ${JSON.stringify(t, undefined, 2)}`;
        };
        options.onYear = (y) => {
            console.log(`%cjDatePicker.js [onYear] ::: ${JSON.stringify(y, undefined, 2)}`, 'background:#1b709e;color:#fff;padding:3px 5px;');
            res.innerHTML += "\r\n-------------------------------\r\n" + `[onYear] ::: ${JSON.stringify(y, undefined, 2)}`;
        };
    
        const d = new jDatePicker(options);
                
        d.open();
        
        res.innerHTML = '';
        res.textContent = `const options = ${JSON.stringify(options, undefined, 2)};`;
    });


});